pub struct SpawnConfig {
pub model: Option<String>,
pub reasoning: Option<String>,
pub permission_policy: Option<PermissionPolicy>,
pub env: Vec<(String, String)>,
pub context_window_override_tokens: Option<u32>,
}Expand description
Runtime configuration applied when spawning or resuming a session.
Values in this struct are unified overrides. Each executor translates them to provider-specific settings at call time.
Examples
use unified_agent_sdk::{PermissionPolicy, executor::SpawnConfig};
let config = SpawnConfig {
model: Some("gpt-5-codex".to_string()),
reasoning: Some("medium".to_string()),
permission_policy: Some(PermissionPolicy::Prompt),
env: vec![("RUST_LOG".to_string(), "debug".to_string())],
context_window_override_tokens: Some(128_000),
};
assert_eq!(config.context_window_override_tokens, Some(128_000));Fields
model: Option<String>Optional model override.
reasoning: Option<String>Optional reasoning level/effort override.
permission_policy: Option<PermissionPolicy>Optional permission policy override.
env: Vec<(String, String)>Extra environment variables to forward to the executor process.
context_window_override_tokens: Option<u32>Optional context window capacity override (tokens) used for unified context usage events.